==> claromentis-framework-9.6.6-26891208.zip: web/intranet/core/classes/Event/LazyResolver.php <==
<?php
namespace Claromentis\Core\Event;

$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] ?: array()) + array("_5e30c4717c" . "ed36cff9e93" . "e19a5c576cc" => base64_decode("aXNfc3" . "RyaW5n"), "_ae76ef27ae5b48757f71a202718b5e5" . "e" => base64_decode("Y2FsbF91c2Vy" . "X2Z1bmNfYXJy" . "YXk="));
use Pimple\Container;
use Symfony\Component\EventDispatcher\EventDispatcherInterface as BaseEventDispatcherInterface;















class LazyResolver
{
    protected $events_list;
    protected $container;
    protected $service_name;
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function __construct(Container $app, $service_name, $_0e556da531c586bbe7e57a92634addf5)
    {
        $this->container = $app;
        $this->events_list = $_0e556da531c586bbe7e57a92634addf5;
        $this->service_name = $service_name;
    }
    
    
    
    
    
    
    public function subscribe(BaseEventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        
        
        foreach ($this->events_list as $_2cf093f28f4c7e718a5e8af628894c7b => $_4c4d12d3e4f6cac68e3eecffe9887915) {
            if ($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_5e30c4717ced36cff9e93e19a" . "5c576cc"]($_4c4d12d3e4f6cac68e3eecffe9887915)) {
                $_b497ce6f2af10f67516aed0ecf34d8cf->addListener($_2cf093f28f4c7e718a5e8af628894c7b, array($this, $_4c4d12d3e4f6cac68e3eecffe9887915));
            } elseif ($GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_5e30c4717ced" . "36cff9e93e19a" . "5c576cc"]($_4c4d12d3e4f6cac68e3eecffe9887915[0])) {
                $_b497ce6f2af10f67516aed0ecf34d8cf->addListener($_2cf093f28f4c7e718a5e8af628894c7b, array($this, $_4c4d12d3e4f6cac68e3eecffe9887915[0]), isset($_4c4d12d3e4f6cac68e3eecffe9887915[1]) ? $_4c4d12d3e4f6cac68e3eecffe9887915[1] : 0);
            } else {
                foreach ($_4c4d12d3e4f6cac68e3eecffe9887915 as $_c44578bb3769209a3b3733819fd02602) {
                    $_b497ce6f2af10f67516aed0ecf34d8cf->addListener($_2cf093f28f4c7e718a5e8af628894c7b, array($this, $_c44578bb3769209a3b3733819fd02602[0]), isset($_c44578bb3769209a3b3733819fd02602[1]) ? $_c44578bb3769209a3b3733819fd02602[1] : 0);
                }
            }
        }
        unset($this->events_list);
        
        
    }
    public function __call($_dfd42320291c688f32c87c7179a5604e, $arguments)
    {
        $_4d348406673ac4fa7aebc6394e363899 = $this->container[$this->service_name];
        return $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_ae76ef2" . "7ae5b487" . "57f71a20" . "2718b5e5" . "e"]([$_4d348406673ac4fa7aebc6394e363899, $_dfd42320291c688f32c87c7179a5604e], $arguments);
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/core/classes/Event/LazyResolver.php <==
<?php
namespace Claromentis\Core\Event;

$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"] ?: array()) + array("_5e30c4717ced36cff9e93e19a5" . "c576cc" => base64_decode("aXNfc3Rya" . "W5n"), "_ae76ef27ae5b48757f7" . "1a202718b5e5e" => base64_decode("Y2FsbF91c2" . "VyX2Z1bmNf" . "YXJyYXk="));
use Pimple\Container;
use Symfony\Component\EventDispatcher\EventDispatcherInterface as BaseEventDispatcherInterface;















class LazyResolver
{
    protected $events_list;
    protected $container;
    protected $service_name;
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function __construct(Container $app, $service_name, $_0e556da531c586bbe7e57a92634addf5)
    {
        $this->container = $app;
        $this->events_list = $_0e556da531c586bbe7e57a92634addf5;
        $this->service_name = $service_name;
    }
    
    
    
    
    
    
    public function subscribe(BaseEventDispatcherInterface $_b497ce6f2af10f67516aed0ecf34d8cf)
    {
        
        
        foreach ($this->events_list as $_2cf093f28f4c7e718a5e8af628894c7b => $_4c4d12d3e4f6cac68e3eecffe9887915) {
            if ($GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_5e30c4717ced" . "36cff9e93e19a" . "5c576cc"]($_4c4d12d3e4f6cac68e3eecffe9887915)) {
                $_b497ce6f2af10f67516aed0ecf34d8cf->addListener($_2cf093f28f4c7e718a5e8af628894c7b, array($this, $_4c4d12d3e4f6cac68e3eecffe9887915));
            } elseif ($GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_5e30c471" . "7ced36cff" . "9e93e19a5" . "c576cc"]($_4c4d12d3e4f6cac68e3eecffe9887915[0])) {
                $_b497ce6f2af10f67516aed0ecf34d8cf->addListener($_2cf093f28f4c7e718a5e8af628894c7b, array($this, $_4c4d12d3e4f6cac68e3eecffe9887915[0]), isset($_4c4d12d3e4f6cac68e3eecffe9887915[1]) ? $_4c4d12d3e4f6cac68e3eecffe9887915[1] : 0);
            } else {
                foreach ($_4c4d12d3e4f6cac68e3eecffe9887915 as $_c44578bb3769209a3b3733819fd02602) {
                    $_b497ce6f2af10f67516aed0ecf34d8cf->addListener($_2cf093f28f4c7e718a5e8af628894c7b, array($this, $_c44578bb3769209a3b3733819fd02602[0]), isset($_c44578bb3769209a3b3733819fd02602[1]) ? $_c44578bb3769209a3b3733819fd02602[1] : 0);
                }
            }
        }
        unset($this->events_list);
        
        
    }
    public function __call($_dfd42320291c688f32c87c7179a5604e, $arguments)
    {
        $_4d348406673ac4fa7aebc6394e363899 = $this->container[$this->service_name];
        return $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_ae76ef2" . "7ae5b487" . "57f71a20" . "2718b5e5" . "e"]([$_4d348406673ac4fa7aebc6394e363899, $_dfd42320291c688f32c87c7179a5604e], $arguments);
    }
}
